//-----------------------------------------------------------------
// PT8 ATC Positions.h - Created by fredf
//
// Description: 
// Created: 9/24/2010 9:30:50 AM
//-----------------------------------------------------------------
// Machine Name : PT7/PT8
//
//$Modtime: 9/10/12 12:40p $
//$Revision: 4 $
//$Author: Fredf $

#include "Misc.h"

// ********************************************************
// INDIRECT ADDRESSING SCHEME
// ********************************************************
// use indirect addressing to get to the correct
// positions for each tool
// Q101 = tool position 1 in X
// ...
// Q108 = tool position 8 in X

// Q201 = tool position 1 in Y
// ...
// Q208 = tool position 8 in Y

// Q301 = tool position 1 in Z
// ...
// Q308 = tool position 8 in Z

// M3301 = contains tool position n in X
// M3302 = contains tool position n in Y
// M3303 = contains tool position n in Z
// M3311 = base pointer to M3301
// M3312 = base pointer to M3302
// M3313 = base pointer to M3303

// example:
// point M3301 to first X value in Q vars
// start of Q vars space $8000
// M3301->L:$8065	// this is Q101
// point M3311 to the address of register being point to
// M3311->Y:$4CE5,0,12	// M3301

// by adding index n-1 to M3311, M3301 will contain the
// correct X value for tool position n
// ********************************************************

// define X tool position pointers
#define xToolPosition1			Q1001
#define xToolPosition2			Q1002
#define xToolPosition3			Q1003
#define xToolPosition4			Q1004
#define xToolPosition5			Q1005
#define xToolPosition6			Q1006 
#define xToolPosition7			Q1007
#define xToolPosition8			Q1008

#define xToolPosition			M3301	// master tool position in X
#define xToolIndex				M3311	// set tool number-1 here to get correct position
xToolPosition->L:$8000			// address of Q0
xToolIndex->Y:$4CE5,0,12		// M3301
xToolIndex = 1001				// now points to Q1001

// define Y toolposition pointers
#define yToolPosition1 			Q2001
#define yToolPosition2 			Q2002
#define yToolPosition3 			Q2003
#define yToolPosition4 			Q2004
#define yToolPosition5 			Q2005
#define yToolPosition6 			Q2006
#define yToolPosition7 			Q2007
#define yToolPosition8 			Q2008

#define yToolPosition			M3302	// master tool position in X
#define yToolIndex				M3312	// set tool number-1 here to get correct position
yToolPosition->L:$8000			// address of Q0
yToolIndex->Y:$4CE6,0,12		// M3302
yToolIndex = 2001				// now points to Q2001

// define Z tool position pointers
#define zToolPosMaster			Q3000
#define zToolPosition1			Q3001
#define zToolPosition2			Q3002
#define zToolPosition3			Q3003
#define zToolPosition4			Q3004
#define zToolPosition5			Q3005
#define zToolPosition6			Q3006
#define zToolPosition7			Q3007
#define zToolPosition8			Q3008

#define zToolPosition			M3303	// master tool position in X
#define zToolIndex				M3313	// set tool number-1 here to get correct position
zToolPosition->L:$8000			// address of Q0
zToolIndex->Y:$4CE7,0,12		// M3303
zToolIndex = 3001				// now points to Q3001

#ifdef 0	// these are now defined in the TOOLCHANGERLOCATIONS.TBL
// define actual tool positions in X
// back row
xToolPosition1 = -13.865
xToolPosition2 = -8.131
xToolPosition5 = -5.201
xToolPosition6 = 0.562
// front row
xToolPosition3 = -13.851
xToolPosition4 = -8.101
xToolPosition7 = -5.207
xToolPosition8 = 0.539

// define actual tool positions in Y
// back row
yToolPosition1 = 0.554
yToolPosition2 = 0.570
yToolPosition5 = 0.580
yToolPosition6 = 0.548
// front row
yToolPosition3 = -2.600
yToolPosition4 = -2.630
yToolPosition7 = -2.555
yToolPosition8 = -2.590

// define actual tool positions in Z
// back row
zToolPosMaster  = -9.0	 // for safety - should be -10.725
zToolPosition1 = zToolPosMaster
zToolPosition2 = zToolPosMaster
zToolPosition5 = zToolPosMaster
zToolPosition6 = zToolPosMaster
// front row
zToolPosition3 = zToolPosMaster
zToolPosition4 = zToolPosMaster
zToolPosition7 = zToolPosMaster
zToolPosition8 = zToolPosMaster
#endif

#define zRapid					Q3030
zRapid = 600.0

#define fRapid					Q3033
fRapid = 600.0

#define fSlow					Q3035
fSlow = 300

#define zUnclampedPosition 		Q3031
zUnclampedPosition = 4.000		// was -7.500 - now incremental from zToolPosMaster

#define zClearPosition			Q3032
zClearPosition = -2.7250		// should be -2.725

#define yFrontPosition			Q3034
yFrontPosition = 0.4000

// define the insert positions
#define xInsertPositionLeft 	Q1000
#define xInsertPositionRight 	Q2000
xInsertPositionLeft = (xToolPosition2 - xToolPosition1) / 2.0 + xToolPosition1 
xInsertPositionRight =(xToolPosition8 - xToolPosition7) / 2.0 + xToolPosition7

#define InsertPosition			Q4000	// set this to choose LEFT or RIGHT

// define tool in carrier bit field
#define CarrierHasToolBF		Q5000	// bit field to remember which positions have a tool
#define CarrierHasToolIndex		Q5001	// set this to check if carrier contains tool - 0 based index
#define CarrierHasTool			Q5002	// bool returns if tool in carrier

